@@ -1,15 +1,14 @@
 """Mapping Strategy Interface"""
 from dataclasses import dataclass
-from typing import TYPE_CHECKING, Protocol, runtime_checkable
+from typing import TYPE_CHECKING, Protocol
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from typing import Any, Dict, Optional
 
     from oteapi.models.mappingconfig import MappingConfig
 
 
 @dataclass  # type: ignore[misc]
-@runtime_checkable
 class IMappingStrategy(Protocol):
     """Mapping Strategy Interface."""
 
