@@ -1,15 +1,11 @@
-"""Pydantic Filter Configuration Data Model"""
+"""Pydantic Filter Configuration Data Model."""
 from typing import Dict, Optional
 
 from pydantic import BaseModel, Field
 
 
 class FilterConfig(BaseModel):
-    """Resource Specific Data Filter Configuration
-    query - define a query operation
-    condition - logical statement indicating when a filter should be applied
-    limit - number of items remaining after a filter expression
-    """
+    """Filter Strategy Data Configuration."""
 
     filterType: str = Field(
         ..., description="Type of registered filter strategy. E.g., `filter/sql`."
