@@ -6,16 +6,14 @@ from typing import TYPE_CHECKING
 import requests
 
 from oteapi.datacache import DataCache
-from oteapi.plugins import StrategyFactory
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from typing import Any, Dict, Optional
 
     from oteapi.models import ResourceConfig
 
 
 @dataclass
-@StrategyFactory.register(("scheme", "http"), ("scheme", "https"))
 class HTTPSStrategy:
     """Strategy for retrieving data via http.
 
@@ -26,7 +24,7 @@ class HTTPSStrategy:
 
     """
 
-    resource_config: "ResourceConfig"
+    download_config: "ResourceConfig"
 
     def initialize(
         self, session: "Optional[Dict[str, Any]]" = None
@@ -36,13 +34,13 @@ class HTTPSStrategy:
 
     def get(self, session: "Optional[Dict[str, Any]]" = None) -> "Dict[str, Any]":
         """Download via http/https and store on local cache."""
-        cache = DataCache(self.resource_config.configuration)
+        cache = DataCache(self.download_config.configuration)
         if cache.config.accessKey and cache.config.accessKey in cache:
             key = cache.config.accessKey
         else:
-            if not self.resource_config.downloadUrl:
+            if not self.download_config.downloadUrl:
                 raise ValueError("downloadUrl not defined in configuration.")
-            req = requests.get(self.resource_config.downloadUrl, allow_redirects=True)
+            req = requests.get(self.download_config.downloadUrl, allow_redirects=True)
             key = cache.add(req.content)
 
         return {"key": key}
