@@ -3,16 +3,13 @@
 from dataclasses import dataclass
 from typing import TYPE_CHECKING
 
-from oteapi.plugins import StrategyFactory
-
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from typing import Any, Dict, Optional
 
     from oteapi.models import ResourceConfig
 
 
 @dataclass
-@StrategyFactory.register(("mediaType", "text/csv"))
 class CSVParseStrategy:
     """Parse strategy for CSV files.
 
@@ -22,9 +19,9 @@ class CSVParseStrategy:
 
     """
 
-    resource_config: "ResourceConfig"
+    parse_config: "ResourceConfig"
 
-    def parse(self, session: "Optional[Dict[str, Any]]" = None) -> "Dict[str, Any]":
+    def get(self, session: "Optional[Dict[str, Any]]" = None) -> "Dict[str, Any]":
         """Parse CSV."""
         print("CSV in action!")
         return {}
