@@ -5,16 +5,15 @@ from dataclasses import dataclass
 from typing import TYPE_CHECKING
 
 from oteapi.datacache import DataCache
-from oteapi.plugins.factories import StrategyFactory, create_download_strategy
+from oteapi.plugins import create_strategy
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from typing import Any, Dict, Optional
 
     from oteapi.models import ResourceConfig
 
 
 @dataclass
-@StrategyFactory.register(("mediaType", "text/json"))
 class JSONDataParseStrategy:
     """Parse strategy for JSON.
 
@@ -24,7 +23,7 @@ class JSONDataParseStrategy:
 
     """
 
-    resource_config: "ResourceConfig"
+    parse_config: "ResourceConfig"
 
     def initialize(
         self, session: "Optional[Dict[str, Any]]" = None
@@ -32,11 +31,11 @@ class JSONDataParseStrategy:
         """Initialize."""
         return {}
 
-    def parse(self, session: "Optional[Dict[str, Any]]" = None) -> "Dict[str, Any]":
+    def get(self, session: "Optional[Dict[str, Any]]" = None) -> "Dict[str, Any]":
         """Parse json."""
-        downloader = create_download_strategy(self.resource_config)
+        downloader = create_strategy("download", self.parse_config)
         output = downloader.get()
-        cache = DataCache(self.resource_config.configuration)
+        cache = DataCache(self.parse_config.configuration)
         content = cache.get(output["key"])
 
         if isinstance(content, dict):
